@@ -1088,12 +1088,14 @@ class WordToken(models.Model):
         if form['prev_sem_pred']:
             if 'PrevSemPred' not in outline:
                 outline['PrevSemPred'] = self.getPrevSemPred()
+            if 'ImmedPrevSemPred' not in outline:
                 outline['ImmedPrevSemPred'] = self.getImmediatePrevSemPred()
                 outline['IntermedPrevSemPred'] = self.getIntermedPrevSemPred()
             wanted_fields.extend(['PrevSemPred','ImmedPrevSemPred','IntermedPrevSemPred'])
         if form['foll_sem_pred']:
             if 'FollSemPred' not in outline:
                 outline['FollSemPred'] = self.getFollSemPred()
+            if 'ImmedFollSemPred' not in outline:
                 outline['ImmedFollSemPred'] = self.getImmediateFollSemPred()
                 outline['IntermedFollSemPred'] = self.getIntermedFollSemPred()
             wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred'])
